<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="splitTaskTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 创建分割包装任务-->
      <EstablishpackagingForm
        :currshowlist.sync="showEstablishpackagingForm"
        ref="addOrUpdate"
        :splitTasks="splitTasks"
        @refreshDataList="getData"
      ></EstablishpackagingForm>
    </basic-container>
  </div>
</template>
<script>
import { fetchList } from '@/api/warehouse/splittask'
import ttable from '@/views/common/ztt-table'
import EstablishpackagingForm from './establishpackaging-form'

export default {
  data() {
    return {
      ajaxFun: fetchList,
      multipleSelection: [],
      splitTasks: [], // 可进行下发的分割任务
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'splitTaskTable',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮H
        isSearch: true, // 高级查询按钮
        defaultOrderBy: { column: 'updateTime', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 状态
          {
            minWidth: '120',
            prop: 'status',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            optList: () => {
              return this.getStatusOptionList()
            },
            formatter: (row, column, cellValue) => {
              var formatVal
              if (cellValue === '01unissued') {
                formatVal = '未下达'
              } else if (cellValue === '02issued') {
                formatVal = '已下达'
              }
              return formatVal
            }
          },
          // 分割任务编号
          {
            minWidth: '140',
            prop: 'splitTaskNo',
            label: '编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 客户订单号
          {
            minWidth: '140',
            prop: 'customerOrderNo',
            label: '客户订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 客户名称
          {
            minWidth: '120',
            prop: 'customerName',
            label: '客户名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件号
          {
            minWidth: '120',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 零件名称
          {
            minWidth: '120',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 销售数量
          {
            minWidth: '120',
            prop: 'buyQtyDue',
            label: '销售数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 预留数量
          {
            minWidth: '120',
            prop: 'reservedQuantity',
            label: '预留数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 库位号
          {
            minWidth: '120',
            prop: 'locationNo',
            label: '库位号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // SN号
          {
            minWidth: '120',
            prop: 'partBatchNo',
            label: 'SN号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 载具编号
          {
            minWidth: '120',
            prop: 'vehicleNo',
            label: '载具编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 更新时间
          {
            minWidth: '200',
            prop: 'updateTime',
            label: '更新时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 创建时间
          {
            minWidth: '200',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ],
        toolbar: [
          {
            text: '创建分割包装任务',
            type: 'primary',
            fun: this.addOrUpdateHandle,
            disabled: false,
            permitArr: []
          }
        ],
        operator: false,
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 100,
          minWidth: 100
        }
      },
      showEstablishpackagingForm: false,
      statusOptionList: [
        {
          value: '01unissued',
          label: '未下达'
        },
        {
          value: '02issued',
          label: '已下达'
        }
      ]
    }
  },
  components: {
    EstablishpackagingForm,
    ttable
  },
  methods: {
    // 获取数据列表
    getData() {
      this.$refs.splitTaskTable.getDataList()
    },
    getStatusOptionList() {
      return this.statusOptionList
    },
    handleSelectionChange(val) {
      // 将选中记录赋值给multipleSelection
      this.multipleSelection = val
    },
    // 创建分割包装任务
    addOrUpdateHandle() {
      if (this.multipleSelection.length > 0) {
        this.splitTasks = []
        // 校验，只有未下达的分割任务，才能下达包装任务
        const issuedTask = this.multipleSelection.find((item) => {
          return item.status === '02issued'
        })
        if (issuedTask) {
          this.$message.warning('分割任务已下达')
        } else {
          this.multipleSelection.forEach((item) => {
            this.splitTasks.push(item)
          })
          this.showEstablishpackagingForm = true
        }
      } else {
        this.$message.warning('请选择分割任务')
      }
    }
  }
}
</script>
